# Документация Виро

Vyro сочетает Python DX с механизмом выполнения Rust для высокопроизводительных API.

## Что ты можешь сделать

- Создайте асинхронные API с помощью `Vyro()`.
- Запускайте службы с помощью `vyro run`.
- Генерация контрактов API с помощью OpenAPI.
- Управление производственными сервисами с помощью примитивов наблюдения и безопасности.

## Начните здесь

1. Прочтите [Установка](getting-started/installation.md)
2. Следуйте инструкциям [Quickstart](getting-started/quickstart.md).
3. Создайте свою первую конечную точку в [First API](getting-started/first-api.md).